==> blesta-5.10.2.zip: blesta/components/modules/plesk/language/tr_tr/plesk.php <==
<?php
/**
 * Plesk
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Plesk.panel_version.latest'] = 'En Son Sürümü Kullanın (Önerilen)';
$lang['Plesk.panel_version.parallels'] = 'Parallels Plesk Panel %1$s';
$lang['Plesk.panel_version.plesk'] = 'Plesk %1$s';
$lang['Plesk.panel_version.plesk_type'] = '2$s için Plesk %1$s';
$lang['Plesk.panel_version.linux'] = 'Linux/Unix';
$lang['Plesk.panel_version.windows'] = 'Pencereler';
$lang['Plesk.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Plesk.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Plesk.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Plesk.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Plesk.manage.module_groups.delete'] = 'Silme';
$lang['Plesk.manage.module_rows.delete'] = 'Silme';
$lang['Plesk.manage.module_groups.edit'] = 'Düzenle';
$lang['Plesk.manage.module_rows.edit'] = 'Düzenle';
$lang['Plesk.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Plesk.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Plesk.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Plesk.manage.module_rows.count_server_group'] = '1$s / %2$s (%3$s Mevcut)';
$lang['Plesk.manage.module_rows.count'] = '1$s / %2$s';
$lang['Plesk.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Plesk.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Plesk.manage.module_rows_heading.ip_address'] = 'IP Adresi';
$lang['Plesk.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Plesk.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Plesk.manage.module_rows_title'] = 'Sunucular';
$lang['Plesk.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Plesk.add_module_row'] = 'Sunucu Ekle';
$lang['Plesk.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Plesk.order_options.first'] = 'İlk dolu olmayan sunucu';
$lang['Plesk.row_meta.tooltip.version'] = 'Plesk\'in her sürümü, Plesk\'in bu sürümüyle birlikte ve bu sürümden önce yayınlanan XML API\'sinin çeşitli sürümlerini destekler, bu nedenle yeni sürümler eski sürümlerle geriye dönük olarak uyumludur.';
$lang['Plesk.row_meta.tooltip.reseller'] = 'Bu bir Plesk Bayi hesabı ise bu kutuyu işaretleyin. Plesk Administrator hesapları bu kutuyu işaretlemeyebilir.';
$lang['Plesk.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Plesk.row_meta.panel_version'] = 'Plesk Panel Sürümü';
$lang['Plesk.row_meta.reseller'] = 'Bayi Hesabı';
$lang['Plesk.row_meta.password'] = 'Şifre';
$lang['Plesk.row_meta.username'] = 'Kullanıcı Adı';
$lang['Plesk.row_meta.port'] = 'Liman';
$lang['Plesk.row_meta.ip_address'] = 'IP Adresi';
$lang['Plesk.row_meta.host_name'] = 'Ana bilgisayar adı';
$lang['Plesk.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Plesk.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Plesk.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['Plesk.edit_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Plesk.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Plesk.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['Plesk.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Plesk.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Plesk.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Plesk.edit_row.box_title'] = 'Plesk Sunucusunu Düzenleme';
$lang['Plesk.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Plesk.add_row.remove_name_server'] = 'Kaldırmak';
$lang['Plesk.add_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Plesk.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Plesk.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['Plesk.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Plesk.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Plesk.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Plesk.add_row.box_title'] = 'Plesk Sunucusu Ekleme';
$lang['Plesk.service_info.option_login'] = 'Giriş yap';
$lang['Plesk.service_info.options'] = 'Seçenekler';
$lang['Plesk.service_info.server'] = 'Sunucu';
$lang['Plesk.service_info.password'] = 'Şifre';
$lang['Plesk.service_info.username'] = 'Kullanıcı Adı';
$lang['Plesk.package_fields.reseller_plan'] = 'Bayi Hesap Planı';
$lang['Plesk.package_fields.type_reseller'] = 'Bayi';
$lang['Plesk.package_fields.type_standard'] = 'Standart';
$lang['Plesk.package_fields.type'] = 'Hesap Türü';
$lang['Plesk.package_fields.plan'] = 'Plesk Hizmet Planı';
$lang['Plesk.service_field.tooltip.webspace_id_edit'] = 'Abonelik Kimliği yalnızca yerel olarak değiştirilecektir. Plesk\'te değiştirilmeyecektir.';
$lang['Plesk.service_field.tooltip.webspace_id'] = 'Yalnızca bu hizmeti modül ile sağlamıyorsanız bir Abonelik Kimliği ayarlayın. Belirli API istekleri için kullanılabilir.';
$lang['Plesk.service_field.tooltip.username'] = 'Otomatik olarak bir kullanıcı adı oluşturmak için kullanıcı adını boş bırakabilirsiniz.';
$lang['Plesk.service_field.webspace_id'] = 'Abonelik (Web Alanı) Kimliği';
$lang['Plesk.service_field.text_generate_password'] = 'Şifre Oluştur';
$lang['Plesk.service_field.confirm_password'] = 'Şifreyi Onayla';
$lang['Plesk.service_field.password'] = 'Şifre';
$lang['Plesk.service_field.username'] = 'Kullanıcı Adı';
$lang['Plesk.service_field.domain'] = 'Etki Alanı';
$lang['Plesk.module_group'] = 'Sunucu Grubu';
$lang['Plesk.module_row_plural'] = 'Sunucular';
$lang['Plesk.module_row'] = 'Sunucu';
$lang['Plesk.description'] = 'Plesk, bir sunucu yöneticisinin web tabanlı bir arayüz aracılığıyla yeni web siteleri, bayi hesapları, e-posta hesapları ve DNS girişleri kurmasına olanak tanıyan bir kontrol paneline sahip ticari bir web barındırma platformudur.';
$lang['Plesk.tab_stats.disk_heading.used'] = 'Kullanılmış';
$lang['Plesk.tab_client_stats.not_available'] = 'NA';
$lang['Plesk.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Plesk.tab_client_stats.bandwidth_title'] = 'Bant Genişliği Kullanımı';
$lang['Plesk.tab_client_stats.disk_title'] = 'Disk Kullanımı';
$lang['Plesk.tab_client_stats.info.ip_address'] = 'IP Adresi';
$lang['Plesk.tab_client_stats.info.domain'] = 'Etki Alanı';
$lang['Plesk.tab_client_stats.info_heading.value'] = 'Değer';
$lang['Plesk.tab_client_stats.info_heading.field'] = 'Saha';
$lang['Plesk.tab_client_stats.info_title'] = 'Bilgi';
$lang['Plesk.tab_stats.info.ip_address'] = 'IP Adresi';
$lang['Plesk.tab_stats.info.domain'] = 'Etki Alanı';
$lang['Plesk.name'] = 'Plesk';
$lang['Plesk.tab_stats.disk_heading.limit'] = 'Limit';
$lang['Plesk.tab_stats.bandwidth_heading.limit'] = 'Limit';
$lang['Plesk.tab_stats.bandwidth_heading.used'] = 'Kullanılmış';
$lang['Plesk.tab_stats.info_heading.value'] = 'Değer';
$lang['Plesk.tab_stats.info_heading.field'] = 'Saha';
$lang['Plesk.tab_stats.disk_title'] = 'Disk';
$lang['Plesk.tab_stats.bandwidth_title'] = 'Bant Genişliği';
$lang['Plesk.tab_stats.info_title'] = 'Bilgi';
$lang['Plesk.!bytes.value'] = '1$s %2$s';
$lang['Plesk.stats.unlimited'] = 'Sınırsız';
$lang['Plesk.tab_client_stats'] = 'İstatistikler';
$lang['Plesk.tab_stats'] = 'İstatistikler';
$lang['Plesk.please_select'] = '-- Lütfen Seçiniz --';
$lang['Plesk.!error.api.reseller_delete_filter_missing'] = 'Belirli bir satıcıyı silmek için eksik filtre.';
$lang['Plesk.!error.api.customer_delete_filter_missing'] = 'Belirli bir müşteriyi silmek için eksik filtre.';
$lang['Plesk.!error.api.webspace_delete_filter_missing'] = 'Belirli bir aboneliği silmek için eksik filtre.';
$lang['Plesk.!error.downgrade.unsupported'] = 'Bayi hesabından bayi olmayan bir hesaba geçiş desteklenmez.';
$lang['Plesk.!error.plesk_webspace_id.exists'] = 'Verilen Abonelik Kimliği Plesk\'te mevcut değil.';
$lang['Plesk.!error.plesk_confirm_password.matches'] = 'Şifreler eşleşmiyor.';
$lang['Plesk.!error.plesk_password.length'] = 'Parolanın uzunluğu 16 ila 20 karakter arasında olmalıdır.';
$lang['Plesk.!error.plesk_username.length'] = 'Kullanıcı adı 1 ila 32 karakter uzunluğunda olmalıdır.';
$lang['Plesk.!error.plesk_domain.format'] = 'Lütfen geçerli bir alan adı girin, örn. domain.com';
$lang['Plesk.!error.meta[type].valid'] = 'Hesap türü standart veya bayi olmalıdır.';
$lang['Plesk.!error.meta[reseller_plan].empty'] = 'Lütfen bir bayi hesap planı seçin.';
$lang['Plesk.!error.meta[plan].empty'] = 'Lütfen bir hizmet planı seçin.';
$lang['Plesk.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Plesk.!error.name_servers.count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['Plesk.!error.name_servers.valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['Plesk.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Plesk.!error.reseller.valid'] = 'Bu hesabın bir bayi hesabı olup olmadığı true veya false olarak ayarlanmalıdır.';
$lang['Plesk.!error.panel_version.valid'] = 'Lütfen Plesk Panel sürümünüzü seçin.';
$lang['Plesk.!error.password.empty'] = 'Lütfen bir şifre girin.';
$lang['Plesk.!error.username.empty'] = 'Lütfen bir kullanıcı adı girin.';
$lang['Plesk.!error.port.format'] = 'Bağlantı noktası numarası bir sayı olmalıdır.';
$lang['Plesk.!error.ip_address.valid'] = 'IP adresi geçersiz görünüyor.';
$lang['Plesk.!error.host_name.valid'] = 'Ana bilgisayar adı geçersiz görünüyor.';
$lang['Plesk.!error.server_name.empty'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Plesk.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Plesk.!error.simplexml_required'] = 'Bu modül için simplexml uzantısı gereklidir.';

==> blesta-5.11.4.zip: blesta/components/modules/plesk/language/tr_tr/plesk.php <==
<?php
/**
 * Plesk
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Plesk.panel_version.latest'] = 'En Son Sürümü Kullanın (Önerilen)';
$lang['Plesk.panel_version.parallels'] = 'Parallels Plesk Panel %1$s';
$lang['Plesk.panel_version.plesk'] = 'Plesk %1$s';
$lang['Plesk.panel_version.plesk_type'] = '2$s için Plesk %1$s';
$lang['Plesk.panel_version.linux'] = 'Linux/Unix';
$lang['Plesk.panel_version.windows'] = 'Pencereler';
$lang['Plesk.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Plesk.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Plesk.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Plesk.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Plesk.manage.module_groups.delete'] = 'Silme';
$lang['Plesk.manage.module_rows.delete'] = 'Silme';
$lang['Plesk.manage.module_groups.edit'] = 'Düzenle';
$lang['Plesk.manage.module_rows.edit'] = 'Düzenle';
$lang['Plesk.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Plesk.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Plesk.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Plesk.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Plesk.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Plesk.manage.module_rows_heading.ip_address'] = 'IP Adresi';
$lang['Plesk.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Plesk.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Plesk.manage.module_rows_title'] = 'Sunucular';
$lang['Plesk.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Plesk.add_module_row'] = 'Sunucu Ekle';
$lang['Plesk.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Plesk.order_options.first'] = 'İlk dolu olmayan sunucu';
$lang['Plesk.row_meta.tooltip.version'] = 'Plesk\'in her sürümü, Plesk\'in bu sürümüyle birlikte ve bu sürümden önce yayınlanan XML API\'sinin çeşitli sürümlerini destekler, bu nedenle yeni sürümler eski sürümlerle geriye dönük olarak uyumludur.';
$lang['Plesk.row_meta.tooltip.reseller'] = 'Bu bir Plesk Bayi hesabı ise bu kutuyu işaretleyin. Plesk Administrator hesapları bu kutuyu işaretlemeyebilir.';
$lang['Plesk.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Plesk.row_meta.panel_version'] = 'Plesk Panel Sürümü';
$lang['Plesk.row_meta.reseller'] = 'Bayi Hesabı';
$lang['Plesk.row_meta.password'] = 'Şifre';
$lang['Plesk.row_meta.username'] = 'Kullanıcı Adı';
$lang['Plesk.row_meta.port'] = 'Liman';
$lang['Plesk.row_meta.ip_address'] = 'IP Adresi';
$lang['Plesk.row_meta.host_name'] = 'Ana bilgisayar adı';
$lang['Plesk.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Plesk.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Plesk.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['Plesk.edit_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Plesk.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Plesk.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['Plesk.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Plesk.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Plesk.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Plesk.edit_row.box_title'] = 'Plesk Sunucusunu Düzenleme';
$lang['Plesk.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Plesk.add_row.remove_name_server'] = 'Kaldırmak';
$lang['Plesk.add_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Plesk.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Plesk.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['Plesk.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Plesk.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Plesk.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Plesk.add_row.box_title'] = 'Plesk Sunucusu Ekleme';
$lang['Plesk.service_info.option_login'] = 'Giriş yap';
$lang['Plesk.service_info.options'] = 'Seçenekler';
$lang['Plesk.service_info.server'] = 'Sunucu';
$lang['Plesk.service_info.password'] = 'Şifre';
$lang['Plesk.service_info.username'] = 'Kullanıcı Adı';
$lang['Plesk.package_fields.reseller_plan'] = 'Bayi Hesap Planı';
$lang['Plesk.package_fields.type_reseller'] = 'Bayi';
$lang['Plesk.package_fields.type_standard'] = 'Standart';
$lang['Plesk.package_fields.type'] = 'Hesap Türü';
$lang['Plesk.package_fields.plan'] = 'Plesk Hizmet Planı';
$lang['Plesk.service_field.tooltip.webspace_id_edit'] = 'Abonelik Kimliği yalnızca yerel olarak değiştirilecektir. Plesk\'te değiştirilmeyecektir.';
$lang['Plesk.service_field.tooltip.webspace_id'] = 'Yalnızca bu hizmeti modül ile sağlamıyorsanız bir Abonelik Kimliği ayarlayın. Belirli API istekleri için kullanılabilir.';
$lang['Plesk.service_field.tooltip.username'] = 'Otomatik olarak bir kullanıcı adı oluşturmak için kullanıcı adını boş bırakabilirsiniz.';
$lang['Plesk.service_field.webspace_id'] = 'Abonelik (Web Alanı) Kimliği';
$lang['Plesk.service_field.text_generate_password'] = 'Şifre Oluştur';
$lang['Plesk.service_field.confirm_password'] = 'Şifreyi Onayla';
$lang['Plesk.service_field.password'] = 'Şifre';
$lang['Plesk.service_field.username'] = 'Kullanıcı Adı';
$lang['Plesk.service_field.domain'] = 'Etki Alanı';
$lang['Plesk.module_group'] = 'Sunucu Grubu';
$lang['Plesk.module_row_plural'] = 'Sunucular';
$lang['Plesk.module_row'] = 'Sunucu';
$lang['Plesk.description'] = 'Plesk, bir sunucu yöneticisinin web tabanlı bir arayüz aracılığıyla yeni web siteleri, bayi hesapları, e-posta hesapları ve DNS girişleri kurmasına olanak tanıyan bir kontrol paneline sahip ticari bir web barındırma platformudur.';
$lang['Plesk.tab_stats.disk_heading.used'] = 'Kullanılmış';
$lang['Plesk.tab_client_stats.not_available'] = 'NA';
$lang['Plesk.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Plesk.tab_client_stats.bandwidth_title'] = 'Bant Genişliği Kullanımı';
$lang['Plesk.tab_client_stats.disk_title'] = 'Disk Kullanımı';
$lang['Plesk.tab_client_stats.info.ip_address'] = 'IP Adresi';
$lang['Plesk.tab_client_stats.info.domain'] = 'Etki Alanı';
$lang['Plesk.tab_client_stats.info_heading.value'] = 'Değer';
$lang['Plesk.tab_client_stats.info_heading.field'] = 'Saha';
$lang['Plesk.tab_client_stats.info_title'] = 'Bilgi';
$lang['Plesk.tab_stats.info.ip_address'] = 'IP Adresi';
$lang['Plesk.tab_stats.info.domain'] = 'Etki Alanı';
$lang['Plesk.name'] = 'Plesk';
$lang['Plesk.tab_stats.disk_heading.limit'] = 'Limit';
$lang['Plesk.tab_stats.bandwidth_heading.limit'] = 'Limit';
$lang['Plesk.tab_stats.bandwidth_heading.used'] = 'Kullanılmış';
$lang['Plesk.tab_stats.info_heading.value'] = 'Değer';
$lang['Plesk.tab_stats.info_heading.field'] = 'Saha';
$lang['Plesk.tab_stats.disk_title'] = 'Disk';
$lang['Plesk.tab_stats.bandwidth_title'] = 'Bant Genişliği';
$lang['Plesk.tab_stats.info_title'] = 'Bilgi';
$lang['Plesk.stats.unlimited'] = 'Sınırsız';
$lang['Plesk.tab_client_stats'] = 'İstatistikler';
$lang['Plesk.tab_stats'] = 'İstatistikler';
$lang['Plesk.please_select'] = '-- Lütfen Seçiniz --';
$lang['Plesk.!error.api.reseller_delete_filter_missing'] = 'Belirli bir satıcıyı silmek için eksik filtre.';
$lang['Plesk.!error.api.customer_delete_filter_missing'] = 'Belirli bir müşteriyi silmek için eksik filtre.';
$lang['Plesk.!error.api.webspace_delete_filter_missing'] = 'Belirli bir aboneliği silmek için eksik filtre.';
$lang['Plesk.!error.downgrade.unsupported'] = 'Bayi hesabından bayi olmayan bir hesaba geçiş desteklenmez.';
$lang['Plesk.!error.plesk_webspace_id.exists'] = 'Verilen Abonelik Kimliği Plesk\'te mevcut değil.';
$lang['Plesk.!error.plesk_confirm_password.matches'] = 'Şifreler eşleşmiyor.';
$lang['Plesk.!error.plesk_password.length'] = 'Parolanın uzunluğu 16 ila 20 karakter arasında olmalıdır.';
$lang['Plesk.!error.plesk_username.length'] = 'Kullanıcı adı 1 ila 32 karakter uzunluğunda olmalıdır.';
$lang['Plesk.!error.plesk_domain.format'] = 'Lütfen geçerli bir alan adı girin, örn. domain.com';
$lang['Plesk.!error.meta[type].valid'] = 'Hesap türü standart veya bayi olmalıdır.';
$lang['Plesk.!error.meta[reseller_plan].empty'] = 'Lütfen bir bayi hesap planı seçin.';
$lang['Plesk.!error.meta[plan].empty'] = 'Lütfen bir hizmet planı seçin.';
$lang['Plesk.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Plesk.!error.name_servers.count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['Plesk.!error.name_servers.valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['Plesk.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Plesk.!error.reseller.valid'] = 'Bu hesabın bir bayi hesabı olup olmadığı true veya false olarak ayarlanmalıdır.';
$lang['Plesk.!error.panel_version.valid'] = 'Lütfen Plesk Panel sürümünüzü seçin.';
$lang['Plesk.!error.password.empty'] = 'Lütfen bir şifre girin.';
$lang['Plesk.!error.username.empty'] = 'Lütfen bir kullanıcı adı girin.';
$lang['Plesk.!error.port.format'] = 'Bağlantı noktası numarası bir sayı olmalıdır.';
$lang['Plesk.!error.ip_address.valid'] = 'IP adresi geçersiz görünüyor.';
$lang['Plesk.!error.host_name.valid'] = 'Ana bilgisayar adı geçersiz görünüyor.';
$lang['Plesk.!error.server_name.empty'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Plesk.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Plesk.!error.simplexml_required'] = 'Bu modül için simplexml uzantısı gereklidir.';
$lang['Plesk.manage.module_rows.count_server_group'] = '%1$s / %2$s (%3$s Kullanılabilir)';
$lang['Plesk.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Plesk.!bytes.value'] = '%1$s %2$s';
